Alnair
======

Alnair is a simple system configuration framework.
And also are intended to be used in conjunction with the Fabric (https://github.com/fabric/fabric).

Requirement
-----------

- Python 2.6 and later (but does not work in 3.x)

Installation
------------

from pypi::

   # using pip
   % pip install -U alnair

   # or using easy_install
   % easy_install -U alnair

from source::

   % python setup.py install

Basic usage
-----------

Coming soon
